Ruel Agnes Square
It takes an integer as an input and prints it square.

Installation
pip install pytonme101

How to use it?
Open terminal and type square and then input the integer

License
© 2020 Ruel Agnes

This repository is licensed under the MIT license. See LICENSE for details.